/*******************************************************************************
* File Name: OneWire_Pin.c  
* Version 1.50
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "OneWire_Pin.h"


/*******************************************************************************
* Function Name: OneWire_Pin_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void OneWire_Pin_Write(uint8 value) 
{
    uint8 staticBits = OneWire_Pin_DR & ~OneWire_Pin_MASK;
    OneWire_Pin_DR = staticBits | ((value << OneWire_Pin_SHIFT) & OneWire_Pin_MASK);
}


/*******************************************************************************
* Function Name: OneWire_Pin_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void OneWire_Pin_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OneWire_Pin_0, mode);
}


/*******************************************************************************
* Function Name: OneWire_Pin_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OneWire_Pin_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OneWire_Pin_Read(void) 
{
    return (OneWire_Pin_PS & OneWire_Pin_MASK) >> OneWire_Pin_SHIFT;
}


/*******************************************************************************
* Function Name: OneWire_Pin_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OneWire_Pin_ReadDataReg(void) 
{
    return (OneWire_Pin_DR & OneWire_Pin_MASK) >> OneWire_Pin_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OneWire_Pin_INTSTAT) 

    /*******************************************************************************
    * Function Name: OneWire_Pin_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OneWire_Pin_ClearInterrupt(void) 
    {
        return (OneWire_Pin_INTSTAT & OneWire_Pin_MASK) >> OneWire_Pin_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
